summaryrefslogtreecommitdiff
path: root/core/fpdfapi/font/cpdf_type3char.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'core/fpdfapi/font/cpdf_type3char.cpp')
-rw-r--r--core/fpdfapi/font/cpdf_type3char.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/core/fpdfapi/font/cpdf_type3char.cpp b/core/fpdfapi/font/cpdf_type3char.cpp
index 8a89582b00..a04e83c468 100644
--- a/core/fpdfapi/font/cpdf_type3char.cpp
+++ b/core/fpdfapi/font/cpdf_type3char.cpp
@@ -49,15 +49,15 @@ bool CPDF_Type3Char::LoadBitmap(CPDF_RenderContext* pContext) {
m_ImageMatrix = pPageObj->AsImage()->matrix();
{
// |pSource| actually gets assigned a CPDF_DIBSource, which has pointers
// into objects owned by |m_pForm|. Make sure it is out of scope before
// clearing the form.
- RetainPtr<CFX_DIBSource> pSource =
- pPageObj->AsImage()->GetImage()->LoadDIBSource();
+ RetainPtr<CFX_DIBBase> pSource =
+ pPageObj->AsImage()->GetImage()->LoadDIBBase();
- // Clone() is non-virtual, and can't be overloaded by CPDF_DIBSource to
+ // Clone() is non-virtual, and can't be overloaded by CPDF_DIBBase to
// return a clone of the subclass as one would typically expect from a
// such a method. Instead, it only clones the CFX_DIBSource, none of whose
// members point to objects owned by the form. As a result, |m_pBitmap|
// may outlive |m_pForm|.
if (pSource)
@@ -49,15 +49,15 @@ bool CPDF_Type3Char::LoadBitmap(CPDF_RenderContext* pContext) {
m_ImageMatrix = pPageObj->AsImage()->matrix();
{
- // |pSource| actually gets assigned a CPDF_DIBSource, which has pointers
+ // |pSource| actually gets assigned a CPDF_DIBBase, which has pointers
// into objects owned by |m_pForm|. Make sure it is out of scope before
// clearing the form.
@@ -49,15 +49,15 @@ bool CPDF_Type3Char::LoadBitmap(CPDF_RenderContext* pContext) {
// return a clone of the subclass as one would typically expect from a
- // such a method. Instead, it only clones the CFX_DIBSource, none of whose
+ // such a method. Instead, it only clones the CFX_DIBBase, none of whose
// members point to objects owned by the form. As a result, |m_pBitmap|
// may outlive |m_pForm|.